/*=========================================================================

  Program:   Insight Segmentation & Registration Toolkit
  Module:    LittleEndian_img.h
  Language:  C++
  Date:      $Date$
  Version:   $Revision$

  Copyright (c) Insight Software Consortium. All rights reserved.
  See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
     PURPOSE.  See the above copyright notices for more information.

=========================================================================*/
#ifndef __LittleEndian_img_h
#define __LittleEndian_img_h

const unsigned char LittleEndian_img[] = {
  0, 0, 16, 67, 0, 0, 16, 67, 0, 0, 16, 67, 0, 0, 128, 65, 0, 0, 128, 65,
  0, 0, 128, 65, 0, 0, 16, 67, 0, 0, 16, 67, 0, 0, 16, 67, 0, 0, 128, 65,
  0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 16, 67, 0, 0, 16, 67, 0, 0, 16, 67,
  0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 80, 67, 0, 0, 80, 67,
  0, 0, 80, 67, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 80, 67,
  0, 0, 80, 67, 0, 0, 80, 67, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66,
  0, 0, 80, 67, 0, 0, 80, 67, 0, 0, 80, 67, 0, 0, 160, 66, 0, 0, 160, 66,
  0, 0, 160, 66, 0, 0, 16, 67, 0, 0, 16, 67, 0, 0, 16, 67, 0, 0, 128, 65,
  0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 16, 67, 0, 0, 16, 67, 0, 0, 16, 67,
  0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 16, 67, 0, 0, 16, 67,
  0, 0, 16, 67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 80, 67,
  0, 0, 80, 67, 0, 0, 80, 67, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66,
  0, 0, 80, 67, 0, 0, 80, 67, 0, 0, 80, 67, 0, 0, 160, 66, 0, 0, 160, 66,
  0, 0, 160, 66, 0, 0, 80, 67, 0, 0, 80, 67, 0, 0, 80, 67, 0, 0, 160, 66,
  0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 16, 67, 0, 0, 16, 67, 0, 0, 16, 67,
  0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 16, 67, 0, 0, 16, 67,
  0, 0, 16, 67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 16, 67,
  0, 0, 16, 67, 0, 0, 16, 67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65,
  0, 0, 80, 67, 0, 0, 80, 67, 0, 0, 80, 67, 0, 0, 160, 66, 0, 0, 160, 66,
  0, 0, 160, 66, 0, 0, 80, 67, 0, 0, 80, 67, 0, 0, 80, 67, 0, 0, 160, 66,
  0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 80, 67, 0, 0, 80, 67, 0, 0, 80, 67,
  0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 16, 67, 0, 0, 16, 67,
  0, 0, 16, 67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 16, 67,
  0, 0, 16, 67, 0, 0, 16, 67, 0, 0, 128, 65, 0, 0, 128, 65, 0, 0, 128, 65,
  0, 0, 16, 67, 0, 0, 16, 67, 0, 0, 16, 67, 0, 0, 128, 65, 0, 0, 128, 65,
  0, 0, 128, 65, 0, 0, 80, 67, 0, 0, 80, 67, 0, 0, 80, 67, 0, 0, 160, 66,
  0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 80, 67, 0, 0, 80, 67, 0, 0, 80, 67,
  0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 80, 67, 0, 0, 80, 67,
  0, 0, 80, 67, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 160, 66, 0, 0, 48, 67,
  0, 0, 48, 67, 0, 0, 48, 67, 0, 0, 64, 66, 0, 0, 64, 66, 0, 0, 64, 66,
  0, 0, 48, 67, 0, 0, 48, 67, 0, 0, 48, 67, 0, 0, 64, 66, 0, 0, 64, 66,
  0, 0, 64, 66, 0, 0, 48, 67, 0, 0, 48, 67, 0, 0, 48, 67, 0, 0, 64, 66,
  0, 0, 64, 66, 0, 0, 64, 66, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67,
  0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 112, 67, 0, 0, 112, 67,
  0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 112, 67,
  0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 224, 66,
  0, 0, 48, 67, 0, 0, 48, 67, 0, 0, 48, 67, 0, 0, 64, 66, 0, 0, 64, 66,
  0, 0, 64, 66, 0, 0, 48, 67, 0, 0, 48, 67, 0, 0, 48, 67, 0, 0, 64, 66,
  0, 0, 64, 66, 0, 0, 64, 66, 0, 0, 48, 67, 0, 0, 48, 67, 0, 0, 48, 67,
  0, 0, 64, 66, 0, 0, 64, 66, 0, 0, 64, 66, 0, 0, 112, 67, 0, 0, 112, 67,
  0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 112, 67,
  0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 224, 66,
  0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66,
  0, 0, 224, 66, 0, 0, 48, 67, 0, 0, 48, 67, 0, 0, 48, 67, 0, 0, 64, 66,
  0, 0, 64, 66, 0, 0, 64, 66, 0, 0, 48, 67, 0, 0, 48, 67, 0, 0, 48, 67,
  0, 0, 64, 66, 0, 0, 64, 66, 0, 0, 64, 66, 0, 0, 48, 67, 0, 0, 48, 67,
  0, 0, 48, 67, 0, 0, 64, 66, 0, 0, 64, 66, 0, 0, 64, 66, 0, 0, 112, 67,
  0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 224, 66,
  0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66,
  0, 0, 224, 66, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66,
  0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 48, 67, 0, 0, 48, 67, 0, 0, 48, 67,
  0, 0, 64, 66, 0, 0, 64, 66, 0, 0, 64, 66, 0, 0, 48, 67, 0, 0, 48, 67,
  0, 0, 48, 67, 0, 0, 64, 66, 0, 0, 64, 66, 0, 0, 64, 66, 0, 0, 48, 67,
  0, 0, 48, 67, 0, 0, 48, 67, 0, 0, 64, 66, 0, 0, 64, 66, 0, 0, 64, 66,
  0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66, 0, 0, 224, 66,
  0, 0, 224, 66, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 224, 66,
  0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 112, 67, 0, 0, 112, 67, 0, 0, 112, 67,
  0, 0, 224, 66, 0, 0, 224, 66, 0, 0, 224, 66
};

#endif
